@@ -214,32 +214,50 @@ def split_pack_environment(
 
                     extend_js(os.path.join(pack_outdir, f"{pkg_outname}.{i}.js"))
 
-    # create the base js file
-    lines = []
+    # Create the base js file, we either use importScripts if it's available (web worker)
+    # or dynamic import if it's not
+    # We cannot always use dynamic imports, as they are not available yet on Firefox web workers
+    lines = ["if (typeof importScripts !== 'undefined') {"]
+
+    for js_file in js_files:
+        lines.append(f"importScripts('./{js_file}')")
+        lines.append(f"await {export_name}._wait_run_dependencies()")
+
+    lines.append("} else {")
+
     for js_file in js_files:
-        # lines.append(f"    promises.push(import('./{js_file}'));")
         lines.append(f"await import('./{js_file}')")
         lines.append(f"await {export_name}._wait_run_dependencies()")
-    txt = "\n".join(lines)
 
+    lines.append("}")
+
+    function_body = "\n".join(lines)
+
+
+    # browser
     if export_name.startswith("globalThis"):
-        kw = ["","export default"][int(with_export_default_statement)]
-        fname = [" importPackages", ""][int(with_export_default_statement)]
-        js_import_all_func = f"""
-{kw} async function{fname}(){{
-{txt}
-}}
-{export_name}.importPackages = importPackages;
-        """
+        if with_export_default_statement:
+            js_function_source = f"""export default async function(){{
+                {function_body}
+            }}
+            """
+        else:
+            js_function_source = f"""async function importPackages(){{
+                {function_body}
+            }}
+            {export_name}.importPackages = importPackages;
+            """
+    # node
     else:
-        js_import_all_func = f"""async function importPackages(){{
-{txt}
-}}
-module.exports = importPackages
+
+        js_function_source = f"""async function importPackages(){{
+            {function_body}
+        }}
+        module.exports = importPackages;
         """
 
     with open(os.path.join(pack_outdir, f"{outname}.js"), "w") as f:
-        f.write(js_import_all_func)
+        f.write(js_function_source)
 
 
 def pack_repodata(
